# Elements

## Background

```{eval-rst}
.. automodule:: fretboardgtr.elements.background
   :members:
   :undoc-members:
```

## Frets

```{eval-rst}
.. automodule:: fretboardgtr.elements.frets
   :members:
   :undoc-members:
```

## Fret numbers

```{eval-rst}
.. automodule:: fretboardgtr.elements.fret_number
   :members:
   :undoc-members:
```

## Neck Dots

```{eval-rst}
.. automodule:: fretboardgtr.elements.neck_dots
   :members:
   :undoc-members:
```

## Nut

```{eval-rst}
.. automodule:: fretboardgtr.elements.nut
   :members:
   :undoc-members:
```

## String

```{eval-rst}
.. automodule:: fretboardgtr.elements.strings
   :members:
   :undoc-members:
```

## Tuning

```{eval-rst}
.. automodule:: fretboardgtr.elements.tuning
   :members:
   :undoc-members:
```

## Cross

```{eval-rst}
.. automodule:: fretboardgtr.elements.cross
   :members:
   :undoc-members:
```
## Notes

```{eval-rst}
.. automodule:: fretboardgtr.elements.notes
   :members:
   :undoc-members:
```
